==> aliyun-python-sdk-privatelink-1.0.2.tar.gz: aliyun-python-sdk-privatelink-1.0.2/aliyunsdkprivatelink/request/v20200415/ListVpcEndpointServicesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkprivatelink.endpoint import endpoint_data

class ListVpcEndpointServicesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Privatelink', '2020-04-15', 'ListVpcEndpointServices','privatelink')
		self.set_protocol_type('https')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ServiceBusinessStatus(self):
		return self.get_query_params().get('ServiceBusinessStatus')

	def set_ServiceBusinessStatus(self,ServiceBusinessStatus):
		self.add_query_param('ServiceBusinessStatus',ServiceBusinessStatus)

	def get_AutoAcceptEnabled(self):
		return self.get_query_params().get('AutoAcceptEnabled')

	def set_AutoAcceptEnabled(self,AutoAcceptEnabled):
		self.add_query_param('AutoAcceptEnabled',AutoAcceptEnabled)

	def get_ServiceStatus(self):
		return self.get_query_params().get('ServiceStatus')

	def set_ServiceStatus(self,ServiceStatus):
		self.add_query_param('ServiceStatus',ServiceStatus)

	def get_NextToken(self):
		return self.get_query_params().get('NextToken')

	def set_NextToken(self,NextToken):
		self.add_query_param('NextToken',NextToken)

	def get_ServiceName(self):
		return self.get_query_params().get('ServiceName')

	def set_ServiceName(self,ServiceName):
		self.add_query_param('ServiceName',ServiceName)

	def get_MaxResults(self):
		return self.get_query_params().get('MaxResults')

	def set_MaxResults(self,MaxResults):
		self.add_query_param('MaxResults',MaxResults)

	def get_ServiceId(self):
		return self.get_query_params().get('ServiceId')

	def set_ServiceId(self,ServiceId):
		self.add_query_param('ServiceId',ServiceId)

==> aliyun-python-sdk-privatelink-1.0.3.tar.gz: aliyun-python-sdk-privatelink-1.0.3/aliyunsdkprivatelink/request/v20200415/ListVpcEndpointServicesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkprivatelink.endpoint import endpoint_data

class ListVpcEndpointServicesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Privatelink', '2020-04-15', 'ListVpcEndpointServices','privatelink')
		self.set_protocol_type('https')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ServiceBusinessStatus(self):
		return self.get_query_params().get('ServiceBusinessStatus')

	def set_ServiceBusinessStatus(self,ServiceBusinessStatus):
		self.add_query_param('ServiceBusinessStatus',ServiceBusinessStatus)

	def get_AutoAcceptEnabled(self):
		return self.get_query_params().get('AutoAcceptEnabled')

	def set_AutoAcceptEnabled(self,AutoAcceptEnabled):
		self.add_query_param('AutoAcceptEnabled',AutoAcceptEnabled)

	def get_ServiceStatus(self):
		return self.get_query_params().get('ServiceStatus')

	def set_ServiceStatus(self,ServiceStatus):
		self.add_query_param('ServiceStatus',ServiceStatus)

	def get_NextToken(self):
		return self.get_query_params().get('NextToken')

	def set_NextToken(self,NextToken):
		self.add_query_param('NextToken',NextToken)

	def get_ZoneAffinityEnabled(self):
		return self.get_query_params().get('ZoneAffinityEnabled')

	def set_ZoneAffinityEnabled(self,ZoneAffinityEnabled):
		self.add_query_param('ZoneAffinityEnabled',ZoneAffinityEnabled)

	def get_ServiceName(self):
		return self.get_query_params().get('ServiceName')

	def set_ServiceName(self,ServiceName):
		self.add_query_param('ServiceName',ServiceName)

	def get_MaxResults(self):
		return self.get_query_params().get('MaxResults')

	def set_MaxResults(self,MaxResults):
		self.add_query_param('MaxResults',MaxResults)

	def get_ServiceId(self):
		return self.get_query_params().get('ServiceId')

	def set_ServiceId(self,ServiceId):
		self.add_query_param('ServiceId',ServiceId)
